@@ -1,7 +1,6 @@
-#!/usr/bin/python
 #-*- coding: utf-8 -*-
 
-# Copyright 2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2012-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -106,8 +105,8 @@ class TrayUpdateSystem(QtCore.QThread):
                         self.mes_sig.emit('', _('Update aborted'))
                         return 0
                 try:
-                    current_frame = self._parent.localhost_ClientObj.client.\
-                                                 service.get_frame(sid, pid)
+                    client = self._parent.localhost_ClientObj.client
+                    current_frame = client.service.get_frame(sid, pid,"gui")
                 except urllib2.URLError:
                     _print ('client.service.get_entire_frame in'
                             ' TrayIcon Exception')
